autosubmit.git — autosubmit 3.9.1 documentation

# autosubmit.git

class `autosubmit.git.autosubmit_git.` `AutosubmitGit`(expid)

  Class to handle experiment git repository

  Parameters: | expid (str) – experiment identifier

  static `check_commit`(as_conf)

    Function to check uncommited changes

    Parameters: | as_conf (autosubmit.config.AutosubmitConfig) – experiment configuration

  static `clean_git`(as_conf)

    Function to clean space on BasicConfig.LOCAL_ROOT_DIR/git directory.

    Parameters: | as_conf (autosubmit.config.AutosubmitConfig) – experiment configuration

  static `clone_repository`(as_conf, force, hpcarch)

    Clones a specified git repository on the project folder

    Parameters: | as_conf (autosubmit.config.AutosubmitConfig) – experiment configuration force (bool) – if True, it will overwrite any existing clone hpcarch – current main platform
    Returns: | True if clone was successful, False otherwise